netapp_ontap.models.snaplock_log_file API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.snaplock_log_file`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SnaplockLogFileSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SnaplockLogFile object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `base_name: str GET`

    Base name of log file

    Valid choices:

    - legal_hold
    - privileged_delete
    - system
  `expiry_time: ImpreciseDateTime GET`

    Expiry time of the log file in date-time format. Value '9999-12-31T00:00:00Z' indicates infinite expiry time.

    Example: 2058-06-04T19:00:00.000+0000

  `links: SelfLink GET`

    The links field of the snaplock_log_file.

  `path: str GET`

    Absolute path of the log file in the volume

    Example: /snaplock_log/system_logs/20180822_005947_GMT-present

  `size: Size GET`

    Size of the log file in bytes

    Example: 20000